function [varargout] = diffstairplot(binCtrs,cntBefore,cntAfter)

%DIFFSTAIRPLOT - plot difference in before/after for histogram
%
%SYNOPSIS
%   [FIGHAND,CNTDIFF] = diffstairplot(BINCTRS,CNTBEFORE,CNTAFTER)
%
%INPUTS
%   BINCTRS - center of histogram bins
%   CNTBEFORE - bin count before cut
%   CNTAFTER - bin count after cut
%
%OUTPUTS   
%   FIGHAND - handle to figure
%   CNTDIFF - cntBefore - cntAfter
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

%  $Id: diffstairplot.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% CHECK # of inputs
% CALCULATE change in bins
% MAKE stair plot of original bins
% CALCULATE plot vector for difference data
% PLOT difference data on same figure
error(nargchk(3,3,nargin),'struct');
numBins = numel(binCtrs);
if(numel(cntBefore) ~= numBins)
    msgId = 'diffstairplot:badData';
    error(msgId,'%s: Before data does not match # bins',msgId);
end
if(numel(cntAfter) ~= numBins)
    msgId = 'diffstairplot:badData';
    error(msgId,'%s: After data does not match # bins',msgId);
end
cntDiff = cntBefore - cntAfter;
if(nargout > 1)
    varargout{2} = cntDiff;
end
[figHand,stairCnt,stairEdge] = stairhist(binCtrs,cntBefore);
hold on;

figHand = bar(binCtrs,cntDiff,'r');
%  - now we fix things up
%  ** bar-width is full with no lines inbetween
set(figHand(1),'BarWidth',1);
set(figHand(1),'EdgeColor','none');
if(nargout > 0)
    varargout{1} = figHand;
end
hold off;
legend('Data Before','Data Removed')
return
