function [binCnt,binCtr] = limhist(Y,ymin,ymax,nbins)

%LIMHIST - Histogram data between two extremes
%
%SYNOPSIS
%   [BINCNT,BINCTR] = limhist(Y,YMIN,YMAX,NBINS) 
%
% BINCNT, BINCTR are optional. If neither are present then 
%                              the histogram is plotted. 
%INPUT
%   Y - data to be histogrammed
%   YMIN - max values of Y in histogram
%   YMAX - max values of Y in histogram
%   NBIN - # of bins in histogram
%
%OUTPUT
%   BINCNT - bin contents (optional)
%   BINCTR - bin centers (optional)
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: limhist.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

ystep = (ymax-ymin)/nbins;
nsub = 0;
ndat = length(Y);
idx0 = find(Y >= ymin);
idx1 = find(Y(idx0) <= ymax);
ysub = Y(idx0(idx1));
ymid = zeros(1,nbins);
for j=1:nbins
    ymid(j) = ymin + (ystep / 2) + (j-1)*ystep;
end
if(nargout == 0)
    hist(ysub,ymid);
else 
    if(nargout == 1)
        binCnt = hist(ysub,ymid);
    else
        binCnt = hist(ysub,ymid);
        binCtr = ymid;
    end
end
return
